@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 # BSD 2-Clause License
 #
 # Apprise - Push Notification Library.
-# Copyright (c) 2024, Chris Caron <lead2gold@gmail.com>
+# Copyright (c) 2025, Chris Caron <lead2gold@gmail.com>
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -26,52 +25,47 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-import os
-import re
-import sys
-import time
+import contextlib
 import hashlib
 import inspect
+import os
+from os.path import abspath, dirname, join
+import re
+import sys
 import threading
-from .utils import import_module
-from .utils import Singleton
-from .utils import parse_list
-from .utils import path_decode
-from os.path import dirname
-from os.path import abspath
-from os.path import join
+import time
 
 from .logger import logger
+from .utils.disk import path_decode
+from .utils.module import import_module
+from .utils.parse import parse_list
+from .utils.singleton import Singleton
 
 
 class PluginManager(metaclass=Singleton):
-    """
-    Designed to be a singleton object to maintain all initialized loading
-    of modules in memory.
-    """
+    """Designed to be a singleton object to maintain all initialized loading of
+    modules in memory."""
 
     # Description (used for logging)
-    name = 'Singleton Plugin'
+    name = "Singleton Plugin"
 
     # Memory Space
-    _id = 'undefined'
+    _id = "undefined"
 
     # Our Module Python path name
-    module_name_prefix = f'apprise.{_id}'
+    module_name_prefix = f"apprise.{_id}"
 
     # The module path to scan
     module_path = join(abspath(dirname(__file__)), _id)
 
     # For filtering our result when scanning a module
-    module_filter_re = re.compile(r'^(?P<name>((?!_)[A-Za-z0-9]+))$')
+    module_filter_re = re.compile(r"^(?P<name>((?!_)[A-Za-z0-9]+))$")
 
     # thread safe loading
     _lock = threading.Lock()
 
     def __init__(self, *args, **kwargs):
-        """
-        Over-ride our class instantiation to provide a singleton
-        """
+        """Over-ride our class instantiation to provide a singleton."""
 
         self._module_map = None
         self._schema_map = None
@@ -115,22 +109,22 @@ class PluginManager(metaclass=Singleton):
         self._loaded = set()
 
     def unload_modules(self, disable_native=False):
-        """
-        Reset our object and unload all modules
-        """
+        """Reset our object and unload all modules."""
 
         with self._lock:
             if self._custom_module_map:
                 # Handle Custom Module Assignments
                 for meta in self._custom_module_map.values():
-                    if meta['name'] not in self._module_map:
+                    if meta["name"] not in self._module_map:
                         # Nothing to remove
                         continue
 
                     # For the purpose of tidying up un-used modules in memory
-                    loaded = [m for m in sys.modules.keys()
-                              if m.startswith(
-                                  self._module_map[meta['name']]['path'])]
+                    loaded = [
+                        m
+                        for m in sys.modules
+                        if m.startswith(self._module_map[meta["name"]]["path"])
+                    ]
 
                     for module_path in loaded:
                         del sys.modules[module_path]
@@ -154,9 +148,7 @@ class PluginManager(metaclass=Singleton):
             self._paths_previously_scanned = set()
 
     def load_modules(self, path=None, name=None, force=False):
-        """
-        Load our modules into memory
-        """
+        """Load our modules into memory."""
 
         # Default value
         module_name_prefix = self.module_name_prefix if name is None else name
@@ -181,8 +173,8 @@ class PluginManager(metaclass=Singleton):
             # The .py extension is optional as we support loading directories
             # too
             module_re = re.compile(
-                r'^(?P<name>(?!base|_)[a-z0-9_]+)(\.py)?$',
-                re.I)
+                r"^(?P<name>(?!base|_)[a-z0-9_]+)(\.py)?$", re.I
+            )
 
             t_start = time.time()
             for f in os.listdir(module_path):
@@ -193,60 +185,73 @@ class PluginManager(metaclass=Singleton):
                     continue
 
                 # Store our notification/plugin name:
-                module_name = match.group('name')
-                module_pyname = '{}.{}'.format(module_name_prefix, module_name)
+                module_name = match.group("name")
+                module_pyname = f"{module_name_prefix}.{module_name}"
 
                 if module_name in self._module_map:
                     logger.warning(
                         "%s(s) (%s) already loaded; ignoring %s",
-                        self.name, module_name, os.path.join(module_path, f))
+                        self.name,
+                        module_name,
+                        os.path.join(module_path, f),
+                    )
                     continue
 
                 try:
                     module = __import__(
                         module_pyname,
-                        globals(), locals(),
-                        fromlist=[module_name])
+                        globals(),
+                        locals(),
+                        fromlist=[module_name],
+                    )
 
                 except ImportError:
                     # No problem, we can try again another way...
                     module = import_module(
-                        os.path.join(module_path, f), module_pyname)
+                        os.path.join(module_path, f), module_pyname
+                    )
                     if not module:
                         # logging found in import_module and not needed here
                         continue
 
                 module_class = None
-                for m_class in [obj for obj in dir(module)
-                                if self.module_filter_re.match(obj)]:
+                for m_class in [
+                    obj
+                    for obj in dir(module)
+                    if self.module_filter_re.match(obj)
+                ]:
                     # Get our plugin
                     plugin = getattr(module, m_class)
-                    if not hasattr(plugin, 'app_id'):
+                    if not hasattr(plugin, "app_id"):
                         # Filter out non-notification modules
                         logger.trace(
                             "(%s.%s) import failed; no app_id defined in %s",
-                            self.name, m_class, os.path.join(module_path, f))
+                            self.name,
+                            m_class,
+                            os.path.join(module_path, f),
+                        )
                         continue
 
                     # Add our plugin name to our module map
                     self._module_map[module_name] = {
-                        'plugin': set([plugin]),
-                        'module': module,
-                        'path': '{}.{}'.format(
-                            module_name_prefix, module_name),
-                        'native': True,
+                        "plugin": {plugin},
+                        "module": module,
+                        "path": f"{module_name_prefix}.{module_name}",
+                        "native": True,
                     }
 
-                    fn = getattr(plugin, 'schemas', None)
-                    schemas = set([]) if not callable(fn) else fn(plugin)
+                    fn = getattr(plugin, "schemas", None)
+                    schemas = set() if not callable(fn) else fn(plugin)
 
                     # map our schema to our plugin
                     for schema in schemas:
                         if schema in self._schema_map:
                             logger.error(
-                                "{} schema ({}) mismatch detected - {} to {}"
-                                .format(self.name, schema, self._schema_map,
-                                        plugin))
+                                f"{self.name} schema ({schema}) mismatch"
+                                " detected -"
+                                f" {self._schema_map[schema]} already maps to"
+                                f" {plugin}"
+                            )
                             continue
 
                         # Assign plugin
@@ -263,42 +268,45 @@ class PluginManager(metaclass=Singleton):
                     logger.trace(
                         "%s (%s) import failed; no filename/Class "
                         "match found in %s",
-                        self.name, module_name, os.path.join(module_path, f))
+                        self.name,
+                        module_name,
+                        os.path.join(module_path, f),
+                    )
                     continue
 
                 logger.trace(
-                    '{} {} loaded in {:.6f}s'.format(
-                        self.name, module_name, (time.time() - tl_start)))
+                    f"{self.name} {module_name} loaded in"
+                    f" {time.time() - tl_start:.6f}s"
+                )
 
             # Track the directory loaded so we never load it again
             self._loaded.add(module_path)
 
             logger.debug(
-                '{} {}(s) and {} Schema(s) loaded in {:.4f}s'
-                .format(
-                    self.name,
-                    len(self._module_map) - module_count,
-                    len(self._schema_map) - schema_count,
-                    (time.time() - t_start)))
+                f"{self.name} {len(self._module_map) - module_count}(s) and"
+                f" {len(self._schema_map) - schema_count} Schema(s) loaded in"
+                f" {time.time() - t_start:.4f}s"
+            )
 
     def module_detection(self, paths, cache=True):
-        """
-        Leverage the @notify decorator and load all objects found matching
-        this.
-        """
+        """Leverage the @notify decorator and load all objects found matching
+        this."""
         # A simple restriction that we don't allow periods in the filename at
         # all so it can't be hidden (Linux OS's) and it won't conflict with
         # Python path naming.  This also prevents us from loading any python
         # file that starts with an underscore or dash
         # We allow for __init__.py as well
         module_re = re.compile(
-            r'^(?P<name>[_a-z0-9][a-z0-9._-]+)?(\.py)?$', re.I)
+            r"^(?P<name>[_a-z0-9][a-z0-9._-]+)?(\.py)?$", re.I
+        )
 
         # Validate if we're a loadable Python file or not
-        valid_python_file_re = re.compile(r'.+\.py(o|c)?$', re.IGNORECASE)
+        valid_python_file_re = re.compile(r".+\.py(o|c)?$", re.IGNORECASE)
 
         if isinstance(paths, str):
-            paths = [paths, ]
+            paths = [
+                paths,
+            ]
 
         if not paths or not isinstance(paths, (tuple, list)):
             # We're done
@@ -310,19 +318,18 @@ class PluginManager(metaclass=Singleton):
             # another's namespace
             if not (path and valid_python_file_re.match(path)):
                 # Ignore file/module type
-                logger.trace('Plugin Scan: Skipping %s', path)
+                logger.trace("Plugin Scan: Skipping %s", path)
                 return
 
             t_start = time.time()
-            module_name = hashlib.sha1(path.encode('utf-8')).hexdigest()
+            module_name = hashlib.sha1(path.encode("utf-8")).hexdigest()
             module_pyname = "{prefix}.{name}".format(
-                prefix='apprise.custom.module', name=module_name)
+                prefix="apprise.custom.module", name=module_name
+            )
 
             if module_pyname in self._custom_module_map:
                 # First clear out existing entries
-                for schema in \
-                        self._custom_module_map[module_pyname]['notify']\
-                        .keys():
+                for schema in self._custom_module_map[module_pyname]["notify"]:
 
                     # Remove any mapped modules to this file
                     del self._schema_map[schema]
@@ -334,35 +341,39 @@ class PluginManager(metaclass=Singleton):
             module = import_module(path, module_pyname)
             if not module:
                 # No problem, we can't use this object
-                logger.warning('Failed to load custom module: %s', _path)
+                logger.warning("Failed to load custom module: %s", _path)
                 return
 
             # Print our loaded modules if any
             if module_pyname in self._custom_module_map:
                 logger.debug(
-                    'Custom module %s - %d schema(s) (name=%s) '
-                    'loaded in %.6fs', _path,
-                    len(self._custom_module_map[module_pyname]['notify']),
-                    module_name, (time.time() - t_start))
+                    "Custom module %s - %d schema(s) (name=%s) "
+                    "loaded in %.6fs",
+                    _path,
+                    len(self._custom_module_map[module_pyname]["notify"]),
+                    module_name,
+                    (time.time() - t_start),
+                )
 
                 # Add our plugin name to our module map
                 self._module_map[module_name] = {
-                    'plugin': set(),
-                    'module': module,
-                    'path': module_pyname,
-                    'native': False,
+                    "plugin": set(),
+                    "module": module,
+                    "path": module_pyname,
+                    "native": False,
                 }
 
-                for schema, meta in\
-                        self._custom_module_map[module_pyname]['notify']\
-                        .items():
+                for schema, _meta in self._custom_module_map[module_pyname][
+                    "notify"
+                ].items():
 
                     # For mapping purposes; map our element in our main list
-                    self._module_map[module_name]['plugin'].add(
-                        self._schema_map[schema])
+                    self._module_map[module_name]["plugin"].add(
+                        self._schema_map[schema]
+                    )
 
                     # Log our success
-                    logger.info('Loaded custom notification: %s://', schema)
+                    logger.info("Loaded custom notification: %s://", schema)
             else:
                 # The code reaches here if we successfully loaded the Python
                 # module but no hooks/triggers were found. So we can safely
@@ -375,38 +386,42 @@ class PluginManager(metaclass=Singleton):
 
         for _path in paths:
             path = path_decode(_path)
-            if (cache and path in self._paths_previously_scanned) \
-                    or not os.path.exists(path):
+            if (
+                cache and path in self._paths_previously_scanned
+            ) or not os.path.exists(path):
                 # We're done as we've already scanned this
                 continue
 
             # Store our path as a way of hashing it has been handled
             self._paths_previously_scanned.add(path)
 
-            if os.path.isdir(path) and not \
-                    os.path.isfile(os.path.join(path, '__init__.py')):
+            if os.path.isdir(path) and not os.path.isfile(
+                os.path.join(path, "__init__.py")
+            ):
 
-                logger.debug('Scanning for custom plugins in: %s', path)
+                logger.debug("Scanning for custom plugins in: %s", path)
                 for entry in os.listdir(path):
                     re_match = module_re.match(entry)
                     if not re_match:
                         # keep going
-                        logger.trace('Plugin Scan: Ignoring %s', entry)
+                        logger.trace("Plugin Scan: Ignoring %s", entry)
                         continue
 
                     new_path = os.path.join(path, entry)
                     if os.path.isdir(new_path):
                         # Update our path
-                        new_path = os.path.join(path, entry, '__init__.py')
+                        new_path = os.path.join(path, entry, "__init__.py")
                         if not os.path.isfile(new_path):
                             logger.trace(
-                                'Plugin Scan: Ignoring %s',
-                                os.path.join(path, entry))
+                                "Plugin Scan: Ignoring %s",
+                                os.path.join(path, entry),
+                            )
                             continue
 
-                    if not cache or \
-                            (cache and new_path not in
-                             self._paths_previously_scanned):
+                    if not cache or (
+                        cache
+                        and new_path not in self._paths_previously_scanned
+                    ):
                         # Load our module
                         _import_module(new_path)
 
@@ -417,7 +432,7 @@ class PluginManager(metaclass=Singleton):
                     # This logic is safe to apply because we already
                     # validated the directories state above; update our
                     # path
-                    path = os.path.join(path, '__init__.py')
+                    path = os.path.join(path, "__init__.py")
                     if cache and path in self._paths_previously_scanned:
                         continue
 
@@ -428,7 +443,7 @@ class PluginManager(metaclass=Singleton):
                 # must be a match and must have a .py extension
                 if not re_match or not re_match.group(1):
                     # keep going
-                    logger.trace('Plugin Scan: Ignoring %s', path)
+                    logger.trace("Plugin Scan: Ignoring %s", path)
                     continue
 
                 # Load our module
@@ -437,9 +452,7 @@ class PluginManager(metaclass=Singleton):
         return None
 
     def add(self, plugin, schemas=None, url=None, send_func=None):
-        """
-        Ability to manually add Notification services to our stack
-        """
+        """Ability to manually add Notification services to our stack."""
 
         if not self:
             # Lazy load
@@ -448,7 +461,9 @@ class PluginManager(metaclass=Singleton):
         # Acquire a list of schemas
         p_schemas = parse_list(plugin.secure_protocol, plugin.protocol)
         if isinstance(schemas, str):
-            schemas = [schemas, ]
+            schemas = [
+                schemas,
+            ]
 
         elif schemas is None:
             # Default
@@ -457,25 +472,27 @@ class PluginManager(metaclass=Singleton):
         if not schemas or not isinstance(schemas, (set, tuple, list)):
             # We're done
             logger.error(
-                'The schemas provided (type %s) is unsupported; '
-                'loaded from %s.',
+                "The schemas provided (type %s) is unsupported; "
+                "loaded from %s.",
                 type(schemas),
-                send_func.__name__ if send_func else plugin.__class__.__name__)
+                send_func.__name__ if send_func else plugin.__class__.__name__,
+            )
             return False
 
         # Convert our schemas into a set
-        schemas = set([s.lower() for s in schemas]) | set(p_schemas)
+        schemas = {s.lower() for s in schemas} | set(p_schemas)
 
         # Valdation
         conflict = [s for s in schemas if s in self]
         if conflict:
             # we're already handling this schema
             logger.warning(
-                'The schema(s) (%s) are already defined and could not be '
-                'loaded from %s%s.',
-                ', '.join(conflict),
-                'custom notify function ' if send_func else '',
-                send_func.__name__ if send_func else plugin.__class__.__name__)
+                "The schema(s) (%s) are already defined and could not be "
+                "loaded from %s%s.",
+                ", ".join(conflict),
+                "custom notify function " if send_func else "",
+                send_func.__name__ if send_func else plugin.__class__.__name__,
+            )
             return False
 
         if send_func:
@@ -493,37 +510,37 @@ class PluginManager(metaclass=Singleton):
                 self._custom_module_map[module_name] = {
                     # Name can be useful for indexing back into the
                     # _module_map object; this is the key to do it with:
-                    'name': module_name.split('.')[-1],
-
+                    "name": module_name.split(".")[-1],
                     # The path to the module loaded
-                    'path': path,
-
+                    "path": path,
                     # Initialize our template
-                    'notify': {},
+                    "notify": {},
                 }
 
             for schema in schemas:
-                self._custom_module_map[module_name]['notify'][schema] = {
+                self._custom_module_map[module_name]["notify"][schema] = {
                     # The name of the send function the @notify decorator
                     # wrapped
-                    'fn_name': fn_name,
+                    "fn_name": fn_name,
                     # The URL that was provided in the @notify decorator call
                     # associated with the 'on='
-                    'url': url,
+                    "url": url,
                 }
 
         else:
             module_name = hashlib.sha1(
-                ''.join(schemas).encode('utf-8')).hexdigest()
+                "".join(schemas).encode("utf-8")
+            ).hexdigest()
             module_pyname = "{prefix}.{name}".format(
-                prefix='apprise.adhoc.module', name=module_name)
+                prefix="apprise.adhoc.module", name=module_name
+            )
 
             # Add our plugin name to our module map
             self._module_map[module_name] = {
-                'plugin': set([plugin]),
-                'module': None,
-                'path': module_pyname,
-                'native': False,
+                "plugin": {plugin},
+                "module": None,
+                "path": module_pyname,
+                "native": False,
             }
 
         for schema in schemas:
@@ -533,37 +550,29 @@ class PluginManager(metaclass=Singleton):
         return True
 
     def remove(self, *schemas):
-        """
-        Removes a loaded element (if defined)
-        """
+        """Removes a loaded element (if defined)"""
         if not self:
             # Lazy load
             self.load_modules()
 
         for schema in schemas:
-            try:
+            with contextlib.suppress(KeyError):
                 del self[schema]
 
-            except KeyError:
-                pass
-
     def plugins(self, include_disabled=True):
-        """
-        Return all of our loaded plugins
-        """
+        """Return all of our loaded plugins."""
         if not self:
             # Lazy load
             self.load_modules()
 
         for module in self._module_map.values():
-            for plugin in module['plugin']:
+            for plugin in module["plugin"]:
                 if not include_disabled and not plugin.enabled:
                     continue
                 yield plugin
 
     def schemas(self, include_disabled=True):
-        """
-        Return all of our loaded schemas
+        """Return all of our loaded schemas.
 
         if include_disabled == True, then even disabled notifications are
         returned
@@ -573,13 +582,14 @@ class PluginManager(metaclass=Singleton):
             self.load_modules()
 
         # Return our list
-        return list(self._schema_map.keys()) if include_disabled else \
-            [s for s in self._schema_map.keys() if self._schema_map[s].enabled]
+        return (
+            list(self._schema_map.keys())
+            if include_disabled
+            else [s for s in self._schema_map if self._schema_map[s].enabled]
+        )
 
     def disable(self, *schemas):
-        """
-        Disables the modules associated with the specified schemas
-        """
+        """Disables the modules associated with the specified schemas."""
         if not self:
             # Lazy load
             self.load_modules()
@@ -596,9 +606,7 @@ class PluginManager(metaclass=Singleton):
             self._disabled.add(schema)
 
     def enable_only(self, *schemas):
-        """
-        Disables the modules associated with the specified schemas
-        """
+        """Disables the modules associated with the specified schemas."""
         if not self:
             # Lazy load
             self.load_modules()
@@ -609,7 +617,8 @@ class PluginManager(metaclass=Singleton):
         for plugin in self.plugins():
             # Get our plugin's schema list
             p_schemas = set(
-                parse_list(plugin.secure_protocol, plugin.protocol))
+                parse_list(plugin.secure_protocol, plugin.protocol)
+            )
 
             if not schemas & p_schemas:
                 if plugin.enabled:
@@ -627,9 +636,7 @@ class PluginManager(metaclass=Singleton):
                 plugin.enabled = True
 
     def __contains__(self, schema):
-        """
-        Checks if a schema exists
-        """
+        """Checks if a schema exists."""
         if not self:
             # Lazy load
             self.load_modules()
@@ -646,22 +653,25 @@ class PluginManager(metaclass=Singleton):
         plugin = self._schema_map[schema]
 
         # Our list of all schema entries
-        p_schemas = set([schema])
+        p_schemas = {schema}
 
         for key in list(self._module_map.keys()):
-            if plugin in self._module_map[key]['plugin']:
+            if plugin in self._module_map[key]["plugin"]:
                 # Remove our plugin
-                self._module_map[key]['plugin'].remove(plugin)
+                self._module_map[key]["plugin"].remove(plugin)
 
                 # Custom Plugin Entry; Clean up cross reference
-                module_pyname = self._module_map[key]['path']
-                if not self._module_map[key]['native'] and \
-                        module_pyname in self._custom_module_map:
+                module_pyname = self._module_map[key]["path"]
+                if (
+                    not self._module_map[key]["native"]
+                    and module_pyname in self._custom_module_map
+                ):
 
-                    del self.\
-                        _custom_module_map[module_pyname]['notify'][schema]
+                    del self._custom_module_map[module_pyname]["notify"][
+                        schema
+                    ]
 
-                    if not self._custom_module_map[module_pyname]['notify']:
+                    if not self._custom_module_map[module_pyname]["notify"]:
                         #
                         # Last custom loaded element
                         #
@@ -669,20 +679,23 @@ class PluginManager(metaclass=Singleton):
                         # Free up custom object entry
                         del self._custom_module_map[module_pyname]
 
-                if not self._module_map[key]['plugin']:
+                if not self._module_map[key]["plugin"]:
                     #
                     # Last element
                     #
-                    if self._module_map[key]['native']:
+                    if self._module_map[key]["native"]:
                         # Get our plugin's schema list
-                        p_schemas = \
-                            set([s for s in parse_list(
-                                 plugin.secure_protocol, plugin.protocol)
-                                 if s in self._schema_map])
+                        p_schemas = {
+                            s
+                            for s in parse_list(
+                                plugin.secure_protocol, plugin.protocol
+                            )
+                            if s in self._schema_map
+                        }
 
                     # free system memory
-                    if self._module_map[key]['module']:
-                        del sys.modules[self._module_map[key]['path']]
+                    if self._module_map[key]["module"]:
+                        del sys.modules[self._module_map[key]["path"]]
 
                     # free last remaining pointer in module map
                     del self._module_map[key]
@@ -692,9 +705,7 @@ class PluginManager(metaclass=Singleton):
             del self._schema_map[schema]
 
     def __setitem__(self, schema, plugin):
-        """
-        Support fast assigning of Plugin/Notification Objects
-        """
+        """Support fast assigning of Plugin/Notification Objects."""
         if not self:
             # Lazy load
             self.load_modules()
@@ -702,10 +713,9 @@ class PluginManager(metaclass=Singleton):
         # Set default values if not otherwise set
         if not plugin.service_name:
             # Assign service name if one doesn't exist
-            plugin.service_name = f'{schema}://'
+            plugin.service_name = f"{schema}://"
 
-        p_schemas = set(
-            parse_list(plugin.secure_protocol, plugin.protocol))
+        p_schemas = set(parse_list(plugin.secure_protocol, plugin.protocol))
         if not p_schemas:
             # Assign our protocol
             plugin.secure_protocol = schema
@@ -713,17 +723,17 @@ class PluginManager(metaclass=Singleton):
 
         elif schema not in p_schemas:
             # Add our others (if defined)
-            plugin.secure_protocol = \
-                set([schema] + parse_list(plugin.secure_protocol))
+            plugin.secure_protocol = {
+                schema,
+                *parse_list(plugin.secure_protocol),
+            }
             p_schemas.add(schema)
 
         if not self.add(plugin, schemas=p_schemas):
-            raise KeyError('Conflicting Assignment')
+            raise KeyError("Conflicting Assignment")
 
     def __getitem__(self, schema):
-        """
-        Returns the indexed plugin identified by the schema specified
-        """
+        """Returns the indexed plugin identified by the schema specified."""
         if not self:
             # Lazy load
             self.load_modules()
@@ -731,9 +741,7 @@ class PluginManager(metaclass=Singleton):
         return self._schema_map[schema]
 
     def __iter__(self):
-        """
-        Returns an iterator so we can iterate over our loaded modules
-        """
+        """Returns an iterator so we can iterate over our loaded modules."""
         if not self:
             # Lazy load
             self.load_modules()
@@ -741,9 +749,7 @@ class PluginManager(metaclass=Singleton):
         return iter(self._module_map.values())
 
     def __len__(self):
-        """
-        Returns the number of modules/plugins loaded
-        """
+        """Returns the number of modules/plugins loaded."""
         if not self:
             # Lazy load
             self.load_modules()
@@ -751,7 +757,5 @@ class PluginManager(metaclass=Singleton):
         return len(self._module_map)
 
     def __bool__(self):
-        """
-        Determines if object has loaded or not
-        """
-        return True if self._loaded and self._module_map is not None else False
+        """Determines if object has loaded or not."""
+        return bool(self._loaded and self._module_map is not None)
